@@ -1,6 +1,6 @@
 package File::FormatIdentification::RandomSampling::Model;
 # ABSTRACT: methods to identify files using random sampling
-our $VERSION = '0.003'; # VERSION:
+our $VERSION = '0.004'; # VERSION:
 # (c) 2020 by Andreas Romeyke
 # licensed via GPL v3.0 or later
 use strict;
@@ -9,6 +9,7 @@ use feature qw(say);
 use Moose;
 use List::Util qw( any );
 
+
 sub calc_mimetype {
     my $self = shift;
     my $histogram = shift;
@@ -442,7 +443,33 @@ File::FormatIdentification::RandomSampling::Model - methods to identify files us
 
 =head1 VERSION
 
-version 0.003
+version 0.004
+
+=head1 SYNOPSIS
+
+This module is an extension of L<File::FormatIdentification::RandomSampling> to get a good estimation about the mimetype of media (or files). It uses random sampling of sectors to obtain heuristics about the content types.
+
+To check the mimetype of a given binary string:
+
+  my $ff = File::FormatIdentification::RandomSampling->new(); # basic instantiation
+  my $type = $ff->calc_mimetype($buffer); # calc type of given binary string
+
+The model was learned and uses a decision tree. The module is in very early state.
+You should check the files F<cfi_create_training_data.pl> and F<cfi_learn_model.pl> to create own models.
+
+=head1 NAME
+
+File::FormatIdentification::RandomSampling::Model
+
+=head1 SOURCE
+
+The actual development version is available at L<https://art1pirat.spdns.org/art1/crazy-fast-image-scan>
+
+=head1 METHODS
+
+=head2 calc_mimetype
+
+returns string indicating mimetype of a given buffer.
 
 =head1 AUTHOR
 
